.. marshmallow documentation master file

********************************************
marshmallow: simplified object serialization
********************************************

Release v\ |version|. (:doc:`Changelog <changelog>`)

.. admonition:: Sponsor Message

    Input an OpenAPI spec to generate API docs that look as good as Stripe's. `Request a preview <https://form.typeform.com/to/bShdJw7z>`_ of your docs on Fern.

    .. image:: https://github.com/user-attachments/assets/69916225-0d61-4bd7-b3b9-e378557673cb
        :target: https://form.typeform.com/to/bShdJw7z
        :align: center
        :alt: Fern logo

.. include:: about.rst.inc

Upgrading from an older version?
================================

See the :doc:`Upgrading to Newer Releases <upgrading>` page for notes on getting your code up-to-date with the latest version.

Why another library?
=====================

See :doc:`this document <why>` to learn about what makes marshmallow unique.

Sponsors
========

marshmallow is sponsored by `Route4Me <https://route4me.com>`_.

.. image:: https://github.com/user-attachments/assets/018c2e23-032e-4a11-98da-8b6dc25b9054
    :target: https://route4me.com
    :alt: Routing Planner

Support this project by becoming a sponsor (or ask your company to support this project by becoming a sponsor).
Your logo will be displayed here with a link to your website. [`Become a sponsor`_]

.. _`Become a sponsor`: https://opencollective.com/marshmallow#sponsor

Guide
=====

.. toctree::
    :maxdepth: 2

    install
    quickstart
    nesting
    custom_fields
    extending
    examples


API Reference
=============

.. toctree::
    :maxdepth: 2

    api_reference

Project Info
============

.. toctree::
    :maxdepth: 1

    why
    changelog
    upgrading
    ecosystem
    whos_using
    license
    authors
    contributing
    code_of_conduct
    kudos
